==> openshift-model-machineconfig-6.5.1-sources.jar: io/fabric8/openshift/api/model/machineconfig/v1/MachineConfigPoolFluentImpl.java <==
package io.fabric8.openshift.api.model.machineconfig.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class MachineConfigPoolFluentImpl<A extends MachineConfigPoolFluent<A>> extends BaseFluent<A> implements MachineConfigPoolFluent<A>{
  public MachineConfigPoolFluentImpl() {
  }
  public MachineConfigPoolFluentImpl(MachineConfigPool instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private MachineConfigPoolSpecBuilder spec;
  private MachineConfigPoolStatusBuilder status;
  private Map<String,Object> additionalProperties;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public MachineConfigPoolFluent.MetadataNested<A> withNewMetadata() {
    return new MachineConfigPoolFluentImpl.MetadataNestedImpl();
  }
  public MachineConfigPoolFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new MachineConfigPoolFluentImpl.MetadataNestedImpl(item);
  }
  public MachineConfigPoolFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public MachineConfigPoolFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public MachineConfigPoolFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public MachineConfigPoolSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public MachineConfigPoolSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(MachineConfigPoolSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new MachineConfigPoolSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public MachineConfigPoolFluent.SpecNested<A> withNewSpec() {
    return new MachineConfigPoolFluentImpl.SpecNestedImpl();
  }
  public MachineConfigPoolFluent.SpecNested<A> withNewSpecLike(MachineConfigPoolSpec item) {
    return new MachineConfigPoolFluentImpl.SpecNestedImpl(item);
  }
  public MachineConfigPoolFluent.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public MachineConfigPoolFluent.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new MachineConfigPoolSpecBuilder().build());
  }
  public MachineConfigPoolFluent.SpecNested<A> editOrNewSpecLike(MachineConfigPoolSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public MachineConfigPoolStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public MachineConfigPoolStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(MachineConfigPoolStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new MachineConfigPoolStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public MachineConfigPoolFluent.StatusNested<A> withNewStatus() {
    return new MachineConfigPoolFluentImpl.StatusNestedImpl();
  }
  public MachineConfigPoolFluent.StatusNested<A> withNewStatusLike(MachineConfigPoolStatus item) {
    return new MachineConfigPoolFluentImpl.StatusNestedImpl(item);
  }
  public MachineConfigPoolFluent.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public MachineConfigPoolFluent.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new MachineConfigPoolStatusBuilder().build());
  }
  public MachineConfigPoolFluent.StatusNested<A> editOrNewStatusLike(MachineConfigPoolStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    MachineConfigPoolFluentImpl that = (MachineConfigPoolFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
    if (status != null ? !status.equals(that.status) :that.status != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<MachineConfigPoolFluent.MetadataNested<N>> implements MachineConfigPoolFluent.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) MachineConfigPoolFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends MachineConfigPoolSpecFluentImpl<MachineConfigPoolFluent.SpecNested<N>> implements MachineConfigPoolFluent.SpecNested<N>,Nested<N>{
    SpecNestedImpl(MachineConfigPoolSpec item) {
      this.builder = new MachineConfigPoolSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new MachineConfigPoolSpecBuilder(this);
    }
    MachineConfigPoolSpecBuilder builder;
    public N and() {
      return (N) MachineConfigPoolFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends MachineConfigPoolStatusFluentImpl<MachineConfigPoolFluent.StatusNested<N>> implements MachineConfigPoolFluent.StatusNested<N>,Nested<N>{
    StatusNestedImpl(MachineConfigPoolStatus item) {
      this.builder = new MachineConfigPoolStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new MachineConfigPoolStatusBuilder(this);
    }
    MachineConfigPoolStatusBuilder builder;
    public N and() {
      return (N) MachineConfigPoolFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}

==> openshift-model-machineconfig-6.7.2-sources.jar: io/fabric8/openshift/api/model/machineconfig/v1/MachineConfigPoolFluentImpl.java <==
package io.fabric8.openshift.api.model.machineconfig.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class MachineConfigPoolFluentImpl<A extends MachineConfigPoolFluent<A>> extends BaseFluent<A> implements MachineConfigPoolFluent<A>{
  public MachineConfigPoolFluentImpl() {
  }
  public MachineConfigPoolFluentImpl(MachineConfigPool instance) {
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private MachineConfigPoolSpecBuilder spec;
  private MachineConfigPoolStatusBuilder status;
  private Map<String,Object> additionalProperties;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public MachineConfigPoolFluentImpl.MetadataNested<A> withNewMetadata() {
    return new MachineConfigPoolFluentImpl.MetadataNestedImpl();
  }
  public MachineConfigPoolFluentImpl.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new MachineConfigPoolFluentImpl.MetadataNestedImpl(item);
  }
  public MachineConfigPoolFluentImpl.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public MachineConfigPoolFluentImpl.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public MachineConfigPoolFluentImpl.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public MachineConfigPoolSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public MachineConfigPoolSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(MachineConfigPoolSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new MachineConfigPoolSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public MachineConfigPoolFluentImpl.SpecNested<A> withNewSpec() {
    return new MachineConfigPoolFluentImpl.SpecNestedImpl();
  }
  public MachineConfigPoolFluentImpl.SpecNested<A> withNewSpecLike(MachineConfigPoolSpec item) {
    return new MachineConfigPoolFluentImpl.SpecNestedImpl(item);
  }
  public MachineConfigPoolFluentImpl.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public MachineConfigPoolFluentImpl.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new MachineConfigPoolSpecBuilder().build());
  }
  public MachineConfigPoolFluentImpl.SpecNested<A> editOrNewSpecLike(MachineConfigPoolSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public MachineConfigPoolStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public MachineConfigPoolStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(MachineConfigPoolStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new MachineConfigPoolStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public MachineConfigPoolFluentImpl.StatusNested<A> withNewStatus() {
    return new MachineConfigPoolFluentImpl.StatusNestedImpl();
  }
  public MachineConfigPoolFluentImpl.StatusNested<A> withNewStatusLike(MachineConfigPoolStatus item) {
    return new MachineConfigPoolFluentImpl.StatusNestedImpl(item);
  }
  public MachineConfigPoolFluentImpl.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public MachineConfigPoolFluentImpl.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new MachineConfigPoolStatusBuilder().build());
  }
  public MachineConfigPoolFluentImpl.StatusNested<A> editOrNewStatusLike(MachineConfigPoolStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    MachineConfigPoolFluentImpl that = (MachineConfigPoolFluentImpl) o;
    if (!java.util.Objects.equals(apiVersion, that.apiVersion)) return false;

    if (!java.util.Objects.equals(kind, that.kind)) return false;

    if (!java.util.Objects.equals(metadata, that.metadata)) return false;

    if (!java.util.Objects.equals(spec, that.spec)) return false;

    if (!java.util.Objects.equals(status, that.status)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<MachineConfigPoolFluentImpl.MetadataNested<N>> implements MachineConfigPoolFluentImpl.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) MachineConfigPoolFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends MachineConfigPoolSpecFluentImpl<MachineConfigPoolFluentImpl.SpecNested<N>> implements MachineConfigPoolFluentImpl.SpecNested<N>,Nested<N>{
    SpecNestedImpl(MachineConfigPoolSpec item) {
      this.builder = new MachineConfigPoolSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new MachineConfigPoolSpecBuilder(this);
    }
    MachineConfigPoolSpecBuilder builder;
    public N and() {
      return (N) MachineConfigPoolFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends MachineConfigPoolStatusFluentImpl<MachineConfigPoolFluentImpl.StatusNested<N>> implements MachineConfigPoolFluentImpl.StatusNested<N>,Nested<N>{
    StatusNestedImpl(MachineConfigPoolStatus item) {
      this.builder = new MachineConfigPoolStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new MachineConfigPoolStatusBuilder(this);
    }
    MachineConfigPoolStatusBuilder builder;
    public N and() {
      return (N) MachineConfigPoolFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}
